@@ -12,7 +12,7 @@ async def _generate(config_manager: ConfigManager, device: Device):
     try:
         config_manager.process(device)
     except Exception as ex:
-        raise Exception(f"Error generating output for {device.name}: {ex}")
+        raise Exception(f"Error generating output for {device.name}: {ex.__class__.__name__} {ex}")
 
 
 async def _upload(device: Device, output_dir: Path, purge: bool, show_diff: bool):
@@ -21,16 +21,14 @@ async def _upload(device: Device, output_dir: Path, purge: bool, show_diff: bool
 
     client = OpenHaspClient(device)
     uploader = ConfigUploader(output_dir, client)
-    try:
-        info(f"Uploading files to device '{device.name}'...")
-        return uploader.upload(device, purge, show_diff)
-    except Exception as ex:
-        raise Exception(f"Error uploading files to '{device.name}': {ex}")
+
+    info(f"Uploading files to device '{device.name}'...")
+    return uploader.upload(device, purge, show_diff)
 
 
 async def _deploy(config_manager: ConfigManager, device: Device, output_dir: Path, purge: bool, show_diff: bool):
     await _generate(config_manager, device)
-    changed = _upload(device, output_dir, purge, show_diff)
+    changed = await _upload(device, output_dir, purge, show_diff)
     # _cmd(config_dir, device="touch_down_1", command="reboot", payload="")
     # _reload(config_dir, device)
     if changed:
